# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .meta import Meta
from .company import Company
from .._models import BaseModel

__all__ = ["TimeseryRetrieveResponse", "Data", "DataPoint"]


class DataPoint(BaseModel):
    fiscal_year: int

    period_end: Optional[str] = None

    value: Optional[float] = None


class Data(BaseModel):
    company: Company

    metric: str

    points: List[DataPoint]


class TimeseryRetrieveResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["CompanyListParams"]


class CompanyListParams(TypedDict, total=False):
    cursor: Optional[str]
    """Opaque cursor for keyset pagination"""

    limit: int
    """Results per page"""

    name: Optional[str]

    offset: int
    """Results to skip (ignored when cursor is set)"""

    sector: Optional[str]

    securities_code: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .meta import Meta
from .._models import BaseModel

__all__ = ["DeletedOut", "Data"]


class Data(BaseModel):
    id: int

    deleted: bool


class DeletedOut(BaseModel):
    data: Data

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .meta import Meta
from .._models import BaseModel

__all__ = ["FilingCalendarResponse", "Data"]


class Data(BaseModel):
    date: str

    filing_count: int


class FilingCalendarResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["Translation"]


class Translation(BaseModel):
    model: str

    section: str

    text_en: str

    translated_at: datetime

    source_jp: Optional[str] = None

    token_count: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .company import Company
from .._models import BaseModel

__all__ = ["Peer"]


class Peer(BaseModel):
    company: Company

    fiscal_year: int

    net_income: Optional[int] = None

    revenue: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .meta import Meta
from .._models import BaseModel

__all__ = ["FreshnessRetrieveResponse", "Data"]


class Data(BaseModel):
    filings_this_week: int

    filings_today: int

    total_companies: int

    total_filings: int

    lag_minutes: Optional[int] = None

    last_ingest_at: Optional[str] = None

    last_ingest_status: Optional[str] = None

    next_poll_at: Optional[str] = None


class FreshnessRetrieveResponse(BaseModel):
    data: Data

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from .meta import Meta
from .peer import Peer
from .ratio import Ratio
from .growth import Growth
from .._models import BaseModel
from .financial import Financial
from .translation import Translation
from .health_score import HealthScore

__all__ = ["CompanyRetrieveResponse", "Data"]


class Data(BaseModel):
    """Company with optional expanded sub-resources."""

    created_at: datetime

    edinet_code: str

    name_jp: str

    updated_at: datetime

    financials: Optional[List[Financial]] = None

    fiscal_year_end: Optional[str] = None

    growth: Optional[Growth] = None

    health_score: Optional[HealthScore] = None

    listing: Optional[str] = None

    listing_en: Optional[str] = None

    name_en: Optional[str] = None

    peers: Optional[List[Peer]] = None

    ratios: Optional[List[Ratio]] = None

    sector: Optional[str] = None

    sector_en: Optional[str] = None

    securities_code: Optional[str] = None

    segments: Optional[List[Dict[str, object]]] = None

    translations: Optional[List[Translation]] = None


class CompanyRetrieveResponse(BaseModel):
    data: Data
    """Company with optional expanded sub-resources."""

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .meta import Meta
from .._models import BaseModel

__all__ = [
    "CoverageRetrieveResponse",
    "Data",
    "DataDataSource",
    "DataExchangeBreakdown",
    "DataFilingType",
    "DataFiscalYearDepth",
    "DataFiscalYearRange",
    "DataMetricCoverage",
    "DataSectorBreakdown",
    "DataTotals",
]


class DataDataSource(BaseModel):
    description: str

    name: str

    operator: str

    url: str


class DataExchangeBreakdown(BaseModel):
    companies: int

    listing: str


class DataFilingType(BaseModel):
    count: int

    doc_type: str

    label: str


class DataFiscalYearDepth(BaseModel):
    companies: int

    filings: int

    fiscal_year: int


class DataFiscalYearRange(BaseModel):
    max: Optional[int] = None

    min: Optional[int] = None


class DataMetricCoverage(BaseModel):
    count: int

    coverage_pct: float

    total_filings: int


class DataSectorBreakdown(BaseModel):
    companies: int

    sector: str


class DataTotals(BaseModel):
    companies: int

    filings: int

    financial_data_points: int

    financial_metrics: int

    listed_companies: int

    translated_sections: int


class Data(BaseModel):
    accounting_standards: Dict[str, int]

    data_source: DataDataSource

    exchange_breakdown: List[DataExchangeBreakdown]

    filing_types: List[DataFilingType]

    fiscal_year_depth: List[DataFiscalYearDepth]

    fiscal_year_range: DataFiscalYearRange

    metric_coverage: Dict[str, DataMetricCoverage]

    sector_breakdown: List[DataSectorBreakdown]

    totals: DataTotals

    latest_filing_at: Optional[str] = None


class CoverageRetrieveResponse(BaseModel):
    data: Data

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import date, datetime

from .._models import BaseModel

__all__ = ["Filing"]


class Filing(BaseModel):
    accounting_standard: str

    created_at: datetime

    doc_id: str

    doc_type: str

    edinet_code: str

    fiscal_year: int

    period_end: date

    period_start: date

    received_at: datetime

    doc_description: Optional[str] = None

    doc_type_label: Optional[str] = None

    filed_at: Optional[datetime] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import date

from .._models import BaseModel

__all__ = ["Financial"]


class Financial(BaseModel):
    edinet_code: str

    fiscal_year: int

    period_end: date

    bps: Optional[float] = None

    capex: Optional[int] = None

    capital_stock: Optional[int] = None

    cash_and_equivalents: Optional[int] = None

    comprehensive_income: Optional[int] = None

    cost_of_sales: Optional[int] = None

    currency: Optional[str] = None

    current_assets: Optional[int] = None

    current_liabilities: Optional[int] = None

    data_source: Optional[str] = None

    deferred_tax_assets: Optional[int] = None

    depreciation: Optional[int] = None

    diluted_eps: Optional[float] = None

    dividends_per_share: Optional[float] = None

    eps: Optional[float] = None

    extraordinary_income: Optional[int] = None

    extraordinary_loss: Optional[int] = None

    financing_cf: Optional[int] = None

    goodwill: Optional[int] = None

    gross_profit: Optional[int] = None

    ibd_current: Optional[int] = None

    ibd_noncurrent: Optional[int] = None

    income_before_tax: Optional[int] = None

    intangible_assets: Optional[int] = None

    interest_expense: Optional[int] = None

    interim_dividend: Optional[float] = None

    inventories: Optional[int] = None

    investing_cf: Optional[int] = None

    investment_securities: Optional[int] = None

    net_assets: Optional[int] = None

    net_income: Optional[int] = None

    non_controlling_interests: Optional[int] = None

    noncurrent_assets: Optional[int] = None

    noncurrent_liabilities: Optional[int] = None

    num_employees: Optional[int] = None

    operating_cf: Optional[int] = None

    operating_income: Optional[int] = None

    ordinary_income: Optional[int] = None

    payout_ratio: Optional[float] = None

    pe_ratio: Optional[float] = None

    ppe: Optional[int] = None

    retained_earnings: Optional[int] = None

    revenue: Optional[int] = None

    rnd_expenses: Optional[int] = None

    roe: Optional[float] = None

    sga: Optional[int] = None

    shares_issued: Optional[int] = None

    source_doc_id: Optional[str] = None

    total_assets: Optional[int] = None

    total_equity: Optional[int] = None

    total_liabilities: Optional[int] = None

    trade_payables: Optional[int] = None

    trade_receivables: Optional[int] = None

    treasury_stock: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["Ratio"]


class Ratio(BaseModel):
    fiscal_year: int

    bps: Optional[float] = None

    current_ratio: Optional[float] = None

    debt_to_equity: Optional[float] = None

    dividends_per_share: Optional[float] = None

    eps: Optional[float] = None

    equity_ratio: Optional[float] = None

    gross_margin: Optional[float] = None

    interest_coverage: Optional[float] = None

    net_margin: Optional[float] = None

    num_employees: Optional[int] = None

    operating_margin: Optional[float] = None

    payout_ratio: Optional[float] = None

    pe_ratio: Optional[float] = None

    period_end: Optional[str] = None

    roa: Optional[float] = None

    roe: Optional[float] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["GrowthMetrics"]


class GrowthMetrics(BaseModel):
    eps: Optional[float] = None

    gross_profit: Optional[float] = None

    net_income: Optional[float] = None

    operating_income: Optional[float] = None

    revenue: Optional[float] = None

    total_assets: Optional[float] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .meta import Meta
from .._models import BaseModel

__all__ = ["SectorRetrieveStatsResponse", "Data", "DataAggregates"]


class DataAggregates(BaseModel):
    avg_net_income: Optional[float] = None

    avg_operating_margin: Optional[float] = None

    avg_revenue: Optional[float] = None

    avg_roa: Optional[float] = None

    avg_roe: Optional[float] = None

    max_revenue: Optional[int] = None

    min_revenue: Optional[int] = None

    total_net_income: Optional[int] = None

    total_revenue: Optional[int] = None


class Data(BaseModel):
    aggregates: DataAggregates

    company_count: int

    sector: str


class SectorRetrieveStatsResponse(BaseModel):
    data: Data

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict

from .._models import BaseModel

__all__ = ["HealthCheckDeepResponse"]


class HealthCheckDeepResponse(BaseModel):
    checks: Dict[str, str]

    status: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .meta import Meta
from .filing import Filing
from .._models import BaseModel

__all__ = ["FilingRetrieveResponse"]


class FilingRetrieveResponse(BaseModel):
    data: Filing

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["Company"]


class Company(BaseModel):
    created_at: datetime

    edinet_code: str

    name_jp: str

    updated_at: datetime

    fiscal_year_end: Optional[str] = None

    listing: Optional[str] = None

    listing_en: Optional[str] = None

    name_en: Optional[str] = None

    sector: Optional[str] = None

    sector_en: Optional[str] = None

    securities_code: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .meta import Meta
from .company import Company
from .._models import BaseModel

__all__ = ["RankingRetrieveResponse", "Data"]


class Data(BaseModel):
    company: Company

    fiscal_year: int

    metric: str

    rank: int

    value: Optional[float] = None


class RankingRetrieveResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .growth_metrics import GrowthMetrics

__all__ = ["Growth", "Cagr", "Yoy"]


class Cagr(BaseModel):
    api_3yr: Optional[GrowthMetrics] = FieldInfo(alias="3yr", default=None)

    api_5yr: Optional[GrowthMetrics] = FieldInfo(alias="5yr", default=None)


class Yoy(BaseModel):
    fiscal_year: int

    growth: GrowthMetrics

    period_end: Optional[str] = None


class Growth(BaseModel):
    cagr: Cagr

    yoy: List[Yoy]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .meta import Meta
from .._models import BaseModel

__all__ = ["WebhookCreateResponse", "Data"]


class Data(BaseModel):
    id: int

    active: bool

    created_at: str

    events: List[str]

    secret: str

    url: str


class WebhookCreateResponse(BaseModel):
    data: Data

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .meta import Meta
from .company import Company
from .._models import BaseModel

__all__ = ["CompareRetrieveResponse", "Data", "DataFinancials", "DataRatios"]


class DataFinancials(BaseModel):
    bps: Optional[float] = None

    current_assets: Optional[int] = None

    current_liabilities: Optional[int] = None

    eps: Optional[float] = None

    gross_profit: Optional[int] = None

    net_income: Optional[int] = None

    operating_income: Optional[int] = None

    revenue: Optional[int] = None

    total_assets: Optional[int] = None

    total_equity: Optional[int] = None


class DataRatios(BaseModel):
    equity_ratio: Optional[float] = None

    net_margin: Optional[float] = None

    operating_margin: Optional[float] = None

    roa: Optional[float] = None

    roe: Optional[float] = None


class Data(BaseModel):
    company: Company

    financials: DataFinancials

    fiscal_year: int

    ratios: DataRatios


class CompareRetrieveResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .meta import Meta
from .._models import BaseModel

__all__ = ["TranslationSearchResponse", "Data"]


class Data(BaseModel):
    doc_id: str

    edinet_code: str

    fiscal_year: int

    rank: float

    section: str

    snippet: str

    company_name: Optional[str] = None


class TranslationSearchResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .meta import Meta
from .ratio import Ratio
from .._models import BaseModel

__all__ = ["CompanyRetrieveRatiosResponse"]


class CompanyRetrieveRatiosResponse(BaseModel):
    data: List[Ratio]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["HealthScore"]


class HealthScore(BaseModel):
    components: Dict[str, float]

    computed_at: datetime

    edinet_code: str

    fiscal_year: int

    flags: List[str]

    industry_adjustment: float

    score: int

    data_source: Optional[str] = None

    methodology: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .meta import Meta
from .._models import BaseModel

__all__ = ["WebhookListResponse", "Data"]


class Data(BaseModel):
    id: int

    active: bool

    created_at: str

    events: List[str]

    url: str


class WebhookListResponse(BaseModel):
    data: List[Data]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from axiora import Axiora, AsyncAxiora
from tests.utils import assert_matches_type
from axiora.types import ScreenRetrieveResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestScreen:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Axiora) -> None:
        screen = client.screen.retrieve()
        assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_with_all_params(self, client: Axiora) -> None:
        screen = client.screen.retrieve(
            fiscal_year=1900,
            limit=1,
            net_income_max=0,
            net_income_min=0,
            offset=0,
            operating_income_max=0,
            operating_income_min=0,
            revenue_max=0,
            revenue_min=0,
            roa_max=0,
            roa_min=0,
            roe_max=0,
            roe_min=0,
            sector="sector",
            sort="sort",
        )
        assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Axiora) -> None:
        response = client.screen.with_raw_response.retrieve()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        screen = response.parse()
        assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Axiora) -> None:
        with client.screen.with_streaming_response.retrieve() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            screen = response.parse()
            assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncScreen:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAxiora) -> None:
        screen = await async_client.screen.retrieve()
        assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncAxiora) -> None:
        screen = await async_client.screen.retrieve(
            fiscal_year=1900,
            limit=1,
            net_income_max=0,
            net_income_min=0,
            offset=0,
            operating_income_max=0,
            operating_income_min=0,
            revenue_max=0,
            revenue_min=0,
            roa_max=0,
            roa_min=0,
            roe_max=0,
            roe_min=0,
            sector="sector",
            sort="sort",
        )
        assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAxiora) -> None:
        response = await async_client.screen.with_raw_response.retrieve()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        screen = await response.parse()
        assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAxiora) -> None:
        async with async_client.screen.with_streaming_response.retrieve() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            screen = await response.parse()
            assert_matches_type(ScreenRetrieveResponse, screen, path=["response"])

        assert cast(Any, response.is_closed) is True
